==> CGAL-6.0.1-doc_html.tar.xz: doc_html/Boolean_set_operations_2/annotated.js <==
var annotated =
[
    [ "ArrDirectionalTraits", "namespaceArrDirectionalTraits.html", [
      [ "AreMergeable_2", "classArrDirectionalTraits_1_1AreMergeable__2.html", "classArrDirectionalTraits_1_1AreMergeable__2" ],
      [ "CompareEndpointsXy_2", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html", "classArrDirectionalTraits_1_1CompareEndpointsXy__2" ],
      [ "ConstructOpposite_2", "classArrDirectionalTraits_1_1ConstructOpposite__2.html", "classArrDirectionalTraits_1_1ConstructOpposite__2" ],
      [ "Intersect_2", "classArrDirectionalTraits_1_1Intersect__2.html", "classArrDirectionalTraits_1_1Intersect__2" ],
      [ "Merge_2", "classArrDirectionalTraits_1_1Merge__2.html", "classArrDirectionalTraits_1_1Merge__2" ],
      [ "Split_2", "classArrDirectionalTraits_1_1Split__2.html", "classArrDirectionalTraits_1_1Split__2" ]
    ] ],
    [ "CGAL", null, [
      [ "General_polygon_2", "classCGAL_1_1General__polygon__2.html", "classCGAL_1_1General__polygon__2" ],
      [ "General_polygon_set_2", "classCGAL_1_1General__polygon__set__2.html", "classCGAL_1_1General__polygon__set__2" ],
      [ "Gps_circle_segment_traits_2", "classCGAL_1_1Gps__circle__segment__traits__2.html", null ],
      [ "Gps_default_dcel", "classCGAL_1_1Gps__default__dcel.html", null ],
      [ "Gps_face_base", "classCGAL_1_1Gps__face__base.html", null ],
      [ "Gps_halfedge_base", "classCGAL_1_1Gps__halfedge__base.html", null ],
      [ "Gps_segment_traits_2", "classCGAL_1_1Gps__segment__traits__2.html", "classCGAL_1_1Gps__segment__traits__2" ],
      [ "Gps_traits_2", "classCGAL_1_1Gps__traits__2.html", null ],
      [ "Graphics_scene_options_polygon_set_2", "structCGAL_1_1Graphics__scene__options__polygon__set__2.html", null ],
      [ "Polygon_set_2", "classCGAL_1_1Polygon__set__2.html", null ]
    ] ],
    [ "ArrangementDirectionalXMonotoneTraits_2", "classArrangementDirectionalXMonotoneTraits__2.html", "classArrangementDirectionalXMonotoneTraits__2" ],
    [ "GeneralPolygon_2", "classGeneralPolygon__2.html", "classGeneralPolygon__2" ],
    [ "GeneralPolygonSetDcel", "classGeneralPolygonSetDcel.html", null ],
    [ "GeneralPolygonSetDcelFace", "classGeneralPolygonSetDcelFace.html", "classGeneralPolygonSetDcelFace" ],
    [ "GeneralPolygonSetDcelHalfedge", "classGeneralPolygonSetDcelHalfedge.html", "classGeneralPolygonSetDcelHalfedge" ],
    [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html", "classGeneralPolygonSetTraits__2" ],
    [ "GpsTraitsGeneralPolygon_2", "classGpsTraitsGeneralPolygon__2.html", null ],
    [ "GpsTraitsGeneralPolygonWithHoles_2", "classGpsTraitsGeneralPolygonWithHoles__2.html", null ],
    [ "GraphicsSceneOptionsPolygonSet2", "classGraphicsSceneOptionsPolygonSet2.html", "classGraphicsSceneOptionsPolygonSet2" ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Boolean_set_operations_2/annotated.js <==
var annotated =
[
    [ "ArrDirectionalTraits", "namespaceArrDirectionalTraits.html", [
      [ "AreMergeable_2", "classArrDirectionalTraits_1_1AreMergeable__2.html", "classArrDirectionalTraits_1_1AreMergeable__2" ],
      [ "CompareEndpointsXy_2", "classArrDirectionalTraits_1_1CompareEndpointsXy__2.html", "classArrDirectionalTraits_1_1CompareEndpointsXy__2" ],
      [ "ConstructOpposite_2", "classArrDirectionalTraits_1_1ConstructOpposite__2.html", "classArrDirectionalTraits_1_1ConstructOpposite__2" ],
      [ "Intersect_2", "classArrDirectionalTraits_1_1Intersect__2.html", "classArrDirectionalTraits_1_1Intersect__2" ],
      [ "Merge_2", "classArrDirectionalTraits_1_1Merge__2.html", "classArrDirectionalTraits_1_1Merge__2" ],
      [ "Split_2", "classArrDirectionalTraits_1_1Split__2.html", "classArrDirectionalTraits_1_1Split__2" ]
    ] ],
    [ "CGAL", null, [
      [ "General_polygon_2", "classCGAL_1_1General__polygon__2.html", "classCGAL_1_1General__polygon__2" ],
      [ "General_polygon_set_2", "classCGAL_1_1General__polygon__set__2.html", "classCGAL_1_1General__polygon__set__2" ],
      [ "Gps_circle_segment_traits_2", "classCGAL_1_1Gps__circle__segment__traits__2.html", null ],
      [ "Gps_default_dcel", "classCGAL_1_1Gps__default__dcel.html", null ],
      [ "Gps_face_base", "classCGAL_1_1Gps__face__base.html", null ],
      [ "Gps_halfedge_base", "classCGAL_1_1Gps__halfedge__base.html", null ],
      [ "Gps_segment_traits_2", "classCGAL_1_1Gps__segment__traits__2.html", "classCGAL_1_1Gps__segment__traits__2" ],
      [ "Gps_traits_2", "classCGAL_1_1Gps__traits__2.html", null ],
      [ "Graphics_scene_options_polygon_set_2", "structCGAL_1_1Graphics__scene__options__polygon__set__2.html", null ],
      [ "Polygon_set_2", "classCGAL_1_1Polygon__set__2.html", null ]
    ] ],
    [ "AosDirectionalXMonotoneTraits_2", "classAosDirectionalXMonotoneTraits__2.html", "classAosDirectionalXMonotoneTraits__2" ],
    [ "GeneralPolygon_2", "classGeneralPolygon__2.html", "classGeneralPolygon__2" ],
    [ "GeneralPolygonSetDcel", "classGeneralPolygonSetDcel.html", null ],
    [ "GeneralPolygonSetDcelFace", "classGeneralPolygonSetDcelFace.html", "classGeneralPolygonSetDcelFace" ],
    [ "GeneralPolygonSetDcelHalfedge", "classGeneralPolygonSetDcelHalfedge.html", "classGeneralPolygonSetDcelHalfedge" ],
    [ "GeneralPolygonSetTraits_2", "classGeneralPolygonSetTraits__2.html", "classGeneralPolygonSetTraits__2" ],
    [ "GpsTraitsGeneralPolygon_2", "classGpsTraitsGeneralPolygon__2.html", null ],
    [ "GpsTraitsGeneralPolygonWithHoles_2", "classGpsTraitsGeneralPolygonWithHoles__2.html", null ],
    [ "GraphicsSceneOptionsPolygonSet2", "classGraphicsSceneOptionsPolygonSet2.html", "classGraphicsSceneOptionsPolygonSet2" ]
];
